<template>
    <div class="box">
        <div style="display: flex">
            <el-form
                ref="searchForm"
                :model="searchForm"
                label-width="80px"
                class="searchTop"
            >
                <CascaderCompany
                    :companyIds.sync="searchForm.companyIds"
                    :companyId.sync="searchForm.companyId"
                    :roadSegmentId.sync="searchForm.roadSegmentId"
                    :placeholder="'请选择公司名称'"
                />

                <!-- <el-select
                    v-model="searchForm.roadSegmentId"
                    placeholder="请选择路段"
                    clearable
                >
                    <el-option
                        v-for="item in roadData"
                        :key="item.key"
                        :label="item.value"
                        :value="item.key"
                    >
                    </el-option>
                </el-select> -->
                <dict-select
                    dictCode="qllb"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.category"
                    placeholder="请选择桥梁分类"
                />
                <dict-select
                    dictCode="qlfx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.direction"
                    placeholder="请选择桥梁方向"
                />
                <dict-select
                    dictCode="qllx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.type"
                    placeholder="请选择桥梁类型"
                />
                <el-date-picker
                    v-model="searchForm.finishDay"
                    type="date"
                    placeholder="请选择建成日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-button size="small" @click="findinfo()" type="primary"
                    >查询</el-button
                >
                <el-button size="small" @click="handleReset" type="plain">重置</el-button>
            </el-form>
        </div>
        <el-divider></el-divider>

        <ht-table
            @load="loadData"
            :data="data"
            :pageResult="pageResult"
            :selection="true"
            :show-export="false"
            :show-custom-column="false"
            ref="htTable"
            :default-sorter="[{direction: 'DESC', property: 'id_'}]"
        >
            <template>
                <ht-table-column
                    prop="number"
                    label="桥梁编号"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="name"
                    label="桥梁名称"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="companyName"
                    label="所属公司名称"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="roadSegmentName"
                    label="所在路段"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="officeName"
                    label="管养单位名称"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <!-- <ht-table-column
          prop="centPeg"
          label="中心桩号"
          :sortable="true"
          :show-overflow-tooltip="true"
          width="110"
        >
        </ht-table-column> -->
                <ht-table-column
                    prop="direction"
                    label="桥梁方向"
                    :filters="getDictData('qlfx')"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('qlfx', row.direction) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="type"
                    label="桥梁类型"
                    :filters="getDictData('qllx')"
                    :show-overflow-tooltip="true"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('qllx', row.type) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="category"
                    label="桥梁分类"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('qllb')"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('qllb', row.category) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="spanCombo"
                    label="跨径组合"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="finishDay"
                    label="建设完成日期"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column label="操作" width="150">
                    <template v-slot="{row}">
                        <el-button type="pimary" @click="handleCommand(row)">
                            档案查看
                        </el-button>
                        <!-- <el-dropdown
              size="mini"
              split-button
              @command="handleCommand"
              @click="handleCommand({row, command: 'inspect'})"
            >
              <span> <i class="el-icon-edit"></i>检查记录</span>
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'disease'}"
                  >病害记录</el-dropdown-item
                >
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'curing'}"
                  >养护记录</el-dropdown-item
                >
              </el-dropdown-menu>
            </el-dropdown> -->
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
    </div>
</template>

<script>
import basicData from '@/api/basicData.js'
import routerInfoSelectorcopy from '@/components/selector/routerInfoSelectorcopy.vue'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
export default {
    components: {
        // routerInfoSelectorcopy,
        CascaderCompany,
    },
    data() {
        return {
            data: [],
            searchForm: {},
            roadData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
        }
    },
    created() {
        this.roadData = this.getroad()
    },
    methods: {
        getroad() {
            let arr = []
            basicData.getRoadManagement().then((res) => {
                res.rows.forEach((item) => {
                    arr.push({
                        value: item.name,
                        key: item.id,
                    })
                })
            })
            return arr
        },
        showDialog() {
            this.activeName = '1'
            this.dialogVisible = true
            let form = {
                type: 1,
                category: 1,
                direction: 1,
            }
            this.form = {...form}
        },
        uniqueFunc(arr, uniId) {
            const res = new Map()
            return arr.filter((item) => !res.has(item[uniId]) && res.set(item[uniId], 1))
        },
        handleReset() {
            this.searchForm = {
                ...this.searchForm,
                companyId: ['1419863231459102720'],
                companyIds: '',
                roadSegmentId: '',
                category: '',
                direction: '',
                finishDay: '',
                type: '',
            }
            this.findinfo()
        },
        findinfo() {
            typeof this.$refs.filterTable !== 'undefined' &&
                this.$refs.filterTable.clearFilter()
            let query = []
            let search = {
                company_id_: this.searchForm.companyIds,
                road_segment_id_: this.searchForm.roadSegmentId,
                finish_day_: this.searchForm.finishDay,
                category: this.searchForm.category,
                direction: this.searchForm.direction,
                type: this.searchForm.type,
            }
            for (let i in search) {
                if (search[i]) {
                    if (i == 'company_id_') {
                        query.push({
                            group: 'companyIds',
                            operation: 'IN',
                            parentGroup: '',
                            property: 'COMPANY_ID_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else if (i == 'road_segment_id_') {
                        query.push({
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'road_segment_id_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else {
                        query.push({
                            group: 'advance',
                            operation: 'LIKE',
                            property: i,
                            relation: 'AND',
                            value: search[i],
                        })
                    }
                }
            }
            query = this.uniqueFunc(query, 'property')
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: query,
            }
            this.topQuery = query
            this.$http
                .post('${form}/bizBridgeInformation/v1/getJson', data)
                .then((res) => {
                    console.log(res, '11')
                    let response = res.data
                    this.data = response.rows
                    this.pageResult = {
                        page: response.page,
                        pageSize: response.pageSize,
                        total: response.total,
                    }
                })
        },
        loadData(param, cb) {
            // let r = JSON.stringify(param.pageBean)
            // let l = JSON.stringify(this.pageResult)
            // if (r == l) {
            //   console.log('一样')
            //   param
            // } else {
            //   console.log('不一样')
            //   let query = []
            //   let search = {
            //     companyId: this.searchForm.companyId,
            //     name_: this.searchForm.name,
            //   }
            //   for (let i in search) {
            //     if (search[i]) {
            //       query.push({
            //         group: 'advance',
            //         operation: 'LIKE',
            //         property: i,
            //         relation: 'AND',
            //         value: search[i],
            //       })
            //     }
            //   }
            //   param.querys = query
            // }
            if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
                param.querys = typeof param.querys !== 'undefined' ? param.querys : []
                this.topQuery.forEach((item) => {
                    param.querys.push(item)
                })
                param.querys = this.uniqueFunc(param.querys, 'property')
            }
            this.exportQuery = param
            this.$http
                .post('${form}/bizBridgeInformation/v1/getJson', param)
                .then(
                    (resp) => {
                        let response = resp.data
                        this.data = response.rows
                        this.pageResult = {
                            page: response.page,
                            pageSize: response.pageSize,
                            total: response.total,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        handleCommand(params) {
            let params_ = {
                row: params,
                sign: 'bridge',
            }
            this.$router.push({
                name: 'inspectBridge',
                params: params_,
            })
            //   if (params.command == 'inspect') {
            //     this.$router.push({
            //       name: 'inspectBridge',
            //       params,
            //     })
            //   } else if (params.command == 'disease') {
            //     this.$router.push({
            //       name: 'bridgeDisease',
            //       params,
            //     })
            //   } else if (params.command == 'curing') {
            //     params.sign = 'bridge'
            //     this.$router.push({
            //       name: 'workOrderInfo',
            //       params,
            //     })
            //   }
        },
        // getroad() {
        //   let arr = []
        //   basicData.getRoadManagement().then((res) => {
        //     res.rows.forEach((item) => {
        //       arr.push({
        //         value: item.name,
        //         key: item.id,
        //       })
        //     })
        //   })
        //   return arr
        // },
        //公司赋值
        handleChanged(obj) {
            // console.log(obj.valueInfo.join(','))
            this.formSection.companyIds = JSON.stringify(obj.valueInfo)
            this.formSection.companyName = obj.name
            this.formSection.companyId = obj.id
        },
        companyValue(obj) {
            // console.log(obj)
            this.formSection.companyName = obj.name
            this.formSection.companyId = obj.id
            this.formSection.companyIds = JSON.stringify(obj.id.split(' ')) //必须是空格
        },
        //路线信息赋值
        changed(obj) {
            // console.log(obj)
            this.searchForm.name = obj.name
            this.searchForm.routeId = obj.id
        },
        clear() {
            console.log('进来了')
            this.searchForm.name = ''
            this.searchForm.routeId = ''
        },
    },
}
</script>

<style lang="scss" scoped>
// /deep/.el-card .el-card__body {
//   height: 100% !important;
// }
.box {
    // padding: 10px;
}
// /deep/ .el-main {
//   .el-table {
//     height: 745px !important;
//   }
// }
/deep/ .el-dialog__header {
    border-right: 1px solid #103c5d;
}
//弹出层居中
/deep/ .el-dialog {
    display: flex;
    flex-direction: column;
    margin: 0 !important;
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
}
/deep/ .el-dialog .el-dialog__body {
    flex: 1;
    overflow: auto;
}
/deep/.el-divider--horizontal {
    height: 10px;
    margin: 0 !important;
    position: absolute;
    left: 0;
}
/deep/.ht-table-panel {
    // padding-top: 20px;
    // height: calc(100% - 7%);
    overflow: hidden;
    // background: #fff;
    // display: flex;
    // flex-direction: column;
    // justify-content: space-between;
}
/deep/.ht-quick__search {
    // margin-bottom: 10px;
}
/deep/.ht-table {
    // height: calc(100% - 4vw) !important;
    // max-height: calc(100% - 4vw) !important;
}
/deep/.pagination-panel {
    // padding: 10px 0 0 0;
}
.searchTop > div {
    max-width: 200px;
}
</style>
